@@ -34,7 +34,10 @@ logger = setup_logger(
     "trackme.rest.splk_wlk_power",
     "trackme_rest_api_splk_wlk_power.log",
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -65,9 +68,9 @@ from trackme_libs_bulk_edit import post_bulk_edit, generic_batch_update
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkWlkWrite_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkWlk_v2, self).__init__(
+        super(TrackMeHandlerSplkWlkWrite_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -115,7 +118,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -224,7 +227,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -350,7 +353,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -481,7 +484,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -728,7 +731,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -844,7 +847,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -949,7 +952,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1150,7 +1153,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1381,7 +1384,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1608,7 +1611,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
